Enum notify::Error [−][src]
Errors generated from the notify crate
Variants
Generic(String)Expand description
Generic error
May be used in cases where a platform specific error is mapped to this type
Io(Error)Expand description
I/O errors
The provided path does not exist
Attempted to remove a watch that does not exist