pub enum TargetMode {
TrackPath,
NoTrack,
}Expand description
Indicates what happens when the relationship of the physical entity and the file path changes
Variants
TrackPath
Tracks the file path.
If the underlying physical entity (inode/File ID) at this path is replaced (e.g., by a move/rename operation), the watch continues to monitor the new entity that now occupies the path.
TODO: watching nested non-existent paths is not implemented yet. https://github.com/rolldown/notify/issues/32
NoTrack
Does not track the file path, nor the physical entity.
If the underlying physical entity (inode/File ID) is replaced (e.g., by a move/rename operation), the watch stops monitoring.
TODO: fsevents backend and Windows backend and polling backend does not unwatch on physical entity change yet. https://github.com/rolldown/notify/issues/33