pub struct EventKindMask(/* private fields */);Expand description
A bitmask specifying which event kinds to monitor.
This type allows fine-grained control over which filesystem events are reported. On backends that support kernel-level filtering (inotify), the mask is translated to native flags for optimal performance. On other backends (kqueue, Windows, FSEvents, PollWatcher), filtering is applied in userspace.
Examples
use notify_types::event::EventKindMask;
// Monitor only file creations and deletions
let mask = EventKindMask::CREATE | EventKindMask::REMOVE;
// Monitor everything including access events
let all = EventKindMask::ALL;
// Default: includes all events (matches Config::default())
let default = EventKindMask::default();
assert_eq!(default, EventKindMask::ALL);Implementations
Sourceimpl EventKindMask
impl EventKindMask
Sourcepub const CREATE: EventKindMask
pub const CREATE: EventKindMask
Monitor file/folder creation events.
Sourcepub const REMOVE: EventKindMask
pub const REMOVE: EventKindMask
Monitor file/folder removal events.
Sourcepub const MODIFY_DATA: EventKindMask
pub const MODIFY_DATA: EventKindMask
Monitor data modification events (content/size changes).
Sourcepub const MODIFY_META: EventKindMask
pub const MODIFY_META: EventKindMask
Monitor metadata modification events (permissions, timestamps, etc).
Sourcepub const MODIFY_NAME: EventKindMask
pub const MODIFY_NAME: EventKindMask
Monitor name/rename events.
Sourcepub const ACCESS_OPEN: EventKindMask
pub const ACCESS_OPEN: EventKindMask
Monitor file open events.
Sourcepub const ACCESS_CLOSE: EventKindMask
pub const ACCESS_CLOSE: EventKindMask
Monitor file close events after writing. This fires when a file opened for writing is closed.
Sourcepub const ACCESS_CLOSE_NOWRITE: EventKindMask
pub const ACCESS_CLOSE_NOWRITE: EventKindMask
Monitor file close events after read-only access. This fires when a file opened for reading (not writing) is closed. Note: This can be very noisy and may cause queue overflow on busy systems.
Sourcepub const ALL_MODIFY: EventKindMask
pub const ALL_MODIFY: EventKindMask
All modify events (data, metadata, and name changes).
Sourcepub const ALL_ACCESS: EventKindMask
pub const ALL_ACCESS: EventKindMask
All access events (open, close-write, and close-nowrite).
Sourcepub const CORE: EventKindMask
pub const CORE: EventKindMask
Core events: create, remove, and all modify events. This is the default and matches the current notify behavior (no access events).
Sourcepub const ALL: EventKindMask
pub const ALL: EventKindMask
All events including access events.
Sourceimpl EventKindMask
impl EventKindMask
Sourcepub const fn empty() -> EventKindMask
pub const fn empty() -> EventKindMask
Get a flags value with all bits unset.
Sourcepub const fn all() -> EventKindMask
pub const fn all() -> EventKindMask
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<EventKindMask>
pub const fn from_bits(bits: u32) -> Option<EventKindMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> EventKindMask
pub const fn from_bits_truncate(bits: u32) -> EventKindMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> EventKindMask
pub const fn from_bits_retain(bits: u32) -> EventKindMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<EventKindMask>
pub fn from_name(name: &str) -> Option<EventKindMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: EventKindMask) -> bool
pub const fn intersects(&self, other: EventKindMask) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: EventKindMask) -> bool
pub const fn contains(&self, other: EventKindMask) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: EventKindMask)
pub fn insert(&mut self, other: EventKindMask)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: EventKindMask)
pub fn remove(&mut self, other: EventKindMask)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: EventKindMask)
pub fn toggle(&mut self, other: EventKindMask)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: EventKindMask, value: bool)
pub fn set(&mut self, other: EventKindMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: EventKindMask) -> EventKindMask
pub const fn intersection(self, other: EventKindMask) -> EventKindMask
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: EventKindMask) -> EventKindMask
pub const fn union(self, other: EventKindMask) -> EventKindMask
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: EventKindMask) -> EventKindMask
pub const fn difference(self, other: EventKindMask) -> EventKindMask
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: EventKindMask) -> EventKindMask
pub const fn symmetric_difference(self, other: EventKindMask) -> EventKindMask
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> EventKindMask
pub const fn complement(self) -> EventKindMask
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl EventKindMask
impl EventKindMask
Sourcepub const fn iter(&self) -> Iter<EventKindMask> ⓘ
pub const fn iter(&self) -> Iter<EventKindMask> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<EventKindMask> ⓘ
pub const fn iter_names(&self) -> IterNames<EventKindMask> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl EventKindMask
impl EventKindMask
Sourcepub fn matches(&self, kind: &EventKind) -> bool
pub fn matches(&self, kind: &EventKind) -> bool
Returns whether the given event kind matches this mask.
EventKind::Any and EventKind::Other always pass regardless of the mask,
as they represent meta-events that should not be filtered.
Examples
use notify_types::event::{EventKindMask, EventKind, CreateKind, AccessKind, AccessMode};
let mask = EventKindMask::CREATE;
assert!(mask.matches(&EventKind::Create(CreateKind::File)));
assert!(!mask.matches(&EventKind::Access(AccessKind::Open(AccessMode::Read))));
// Any and Other always pass
let empty = EventKindMask::empty();
assert!(empty.matches(&EventKind::Any));
assert!(empty.matches(&EventKind::Other));Trait Implementations
Sourceimpl Binary for EventKindMask
impl Binary for EventKindMask
Sourceimpl BitAnd for EventKindMask
impl BitAnd for EventKindMask
Sourcefn bitand(self, other: EventKindMask) -> EventKindMask
fn bitand(self, other: EventKindMask) -> EventKindMask
The bitwise and (&) of the bits in self and other.
Sourcetype Output = EventKindMask
type Output = EventKindMask
& operator.Sourceimpl BitAndAssign for EventKindMask
impl BitAndAssign for EventKindMask
Sourcefn bitand_assign(&mut self, other: EventKindMask)
fn bitand_assign(&mut self, other: EventKindMask)
The bitwise and (&) of the bits in self and other.
Sourceimpl BitOr for EventKindMask
impl BitOr for EventKindMask
Sourcefn bitor(self, other: EventKindMask) -> EventKindMask
fn bitor(self, other: EventKindMask) -> EventKindMask
The bitwise or (|) of the bits in self and other.
Sourcetype Output = EventKindMask
type Output = EventKindMask
| operator.Sourceimpl BitOrAssign for EventKindMask
impl BitOrAssign for EventKindMask
Sourcefn bitor_assign(&mut self, other: EventKindMask)
fn bitor_assign(&mut self, other: EventKindMask)
The bitwise or (|) of the bits in self and other.
Sourceimpl BitXor for EventKindMask
impl BitXor for EventKindMask
Sourcefn bitxor(self, other: EventKindMask) -> EventKindMask
fn bitxor(self, other: EventKindMask) -> EventKindMask
The bitwise exclusive-or (^) of the bits in self and other.
Sourcetype Output = EventKindMask
type Output = EventKindMask
^ operator.Sourceimpl BitXorAssign for EventKindMask
impl BitXorAssign for EventKindMask
Sourcefn bitxor_assign(&mut self, other: EventKindMask)
fn bitxor_assign(&mut self, other: EventKindMask)
The bitwise exclusive-or (^) of the bits in self and other.
Sourceimpl Clone for EventKindMask
impl Clone for EventKindMask
Sourcefn clone(&self) -> EventKindMask
fn clone(&self) -> EventKindMask
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreimpl Copy for EventKindMask
Sourceimpl Debug for EventKindMask
impl Debug for EventKindMask
Sourceimpl Default for EventKindMask
impl Default for EventKindMask
Sourcefn default() -> EventKindMask
fn default() -> EventKindMask
impl Eq for EventKindMask
Sourceimpl Extend<EventKindMask> for EventKindMask
impl Extend<EventKindMask> for EventKindMask
Sourcefn extend<T>(&mut self, iterator: T)where
T: IntoIterator<Item = EventKindMask>,
fn extend<T>(&mut self, iterator: T)where
T: IntoIterator<Item = EventKindMask>,
The bitwise or (|) of the bits in each flags value.
Sourcefn extend_one(&mut self, item: T)
fn extend_one(&mut self, item: T)
extend_one)Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
extend_one)Sourceimpl Flags for EventKindMask
impl Flags for EventKindMask
Sourceconst FLAGS: &'static [Flag<EventKindMask>]
const FLAGS: &'static [Flag<EventKindMask>]
Sourcefn from_bits_retain(bits: u32) -> EventKindMask
fn from_bits_retain(bits: u32) -> EventKindMask
Sourcefn all_named() -> EventKindMask
fn all_named() -> EventKindMask
Sourcefn known_bits(&self) -> Self::Bits
fn known_bits(&self) -> Self::Bits
Sourcefn unknown_bits(&self) -> Self::Bits
fn unknown_bits(&self) -> Self::Bits
Sourcefn contains_unknown_bits(&self) -> bool
fn contains_unknown_bits(&self) -> bool
true if any unknown bits are set.Sourcefn from_bits_truncate(bits: Self::Bits) -> Self
fn from_bits_truncate(bits: Self::Bits) -> Self
Sourcefn from_name(name: &str) -> Option<Self>
fn from_name(name: &str) -> Option<Self>
Sourcefn iter_names(&self) -> IterNames<Self> ⓘ
fn iter_names(&self) -> IterNames<Self> ⓘ
Sourcefn iter_defined_names() -> IterDefinedNames<Self> ⓘ
fn iter_defined_names() -> IterDefinedNames<Self> ⓘ
Self::FLAGS.Sourcefn iter_equal_names(&self) -> IterEqualNames<Self> ⓘ
fn iter_equal_names(&self) -> IterEqualNames<Self> ⓘ
Sourcefn intersects(&self, other: Self) -> boolwhere
Self: Sized,
fn intersects(&self, other: Self) -> boolwhere
Self: Sized,
other are also set in self.Sourcefn contains(&self, other: Self) -> boolwhere
Self: Sized,
fn contains(&self, other: Self) -> boolwhere
Self: Sized,
other are also set in self.Sourcefn insert(&mut self, other: Self)where
Self: Sized,
fn insert(&mut self, other: Self)where
Self: Sized,
|) of the bits in self and other.Sourcefn toggle(&mut self, other: Self)where
Self: Sized,
fn toggle(&mut self, other: Self)where
Self: Sized,
^) of the bits in self and other.Sourcefn intersection(self, other: Self) -> Self
fn intersection(self, other: Self) -> Self
&) of the bits in self and other.Sourcefn difference(self, other: Self) -> Self
fn difference(self, other: Self) -> Self
Sourcefn symmetric_difference(self, other: Self) -> Self
fn symmetric_difference(self, other: Self) -> Self
^) of the bits in self and other.Sourcefn complement(self) -> Self
fn complement(self) -> Self
!) of the bits in self, truncating the result.Sourceimpl FromIterator<EventKindMask> for EventKindMask
impl FromIterator<EventKindMask> for EventKindMask
Sourcefn from_iter<T>(iterator: T) -> EventKindMaskwhere
T: IntoIterator<Item = EventKindMask>,
fn from_iter<T>(iterator: T) -> EventKindMaskwhere
T: IntoIterator<Item = EventKindMask>,
The bitwise or (|) of the bits in each flags value.
Sourceimpl Hash for EventKindMask
impl Hash for EventKindMask
Sourceimpl IntoIterator for EventKindMask
impl IntoIterator for EventKindMask
Sourcetype Item = EventKindMask
type Item = EventKindMask
Sourcetype IntoIter = Iter<EventKindMask>
type IntoIter = Iter<EventKindMask>
Sourcefn into_iter(self) -> <EventKindMask as IntoIterator>::IntoIter
fn into_iter(self) -> <EventKindMask as IntoIterator>::IntoIter
Sourceimpl LowerHex for EventKindMask
impl LowerHex for EventKindMask
Sourceimpl Not for EventKindMask
impl Not for EventKindMask
Sourcefn not(self) -> EventKindMask
fn not(self) -> EventKindMask
The bitwise negation (!) of the bits in self, truncating the result.
Sourcetype Output = EventKindMask
type Output = EventKindMask
! operator.Sourceimpl Octal for EventKindMask
impl Octal for EventKindMask
Sourceimpl PartialEq for EventKindMask
impl PartialEq for EventKindMask
impl StructuralPartialEq for EventKindMask
Sourceimpl Sub for EventKindMask
impl Sub for EventKindMask
Sourcefn sub(self, other: EventKindMask) -> EventKindMask
fn sub(self, other: EventKindMask) -> EventKindMask
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcetype Output = EventKindMask
type Output = EventKindMask
- operator.Sourceimpl SubAssign for EventKindMask
impl SubAssign for EventKindMask
Sourcefn sub_assign(&mut self, other: EventKindMask)
fn sub_assign(&mut self, other: EventKindMask)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.