Module notify::op
[−]
[src]
Contains the Op type which describes the actions for which an event is delivered
Structs
| Op |
Detected actions for which an Event is delivered |
Constants
| CHMOD |
Permissions changed |
| CREATE |
Created |
| IGNORED |
Watch has been ignored by the implementation |
| REMOVE |
Removed |
| RENAME |
Renamed |
| WRITE |
Written |